<?php
use In2code\Luxletter\Domain\Model\Configuration;
use In2code\Luxletter\Domain\Model\Newsletter;
use In2code\Luxletter\Domain\Model\Usergroup;

return [
    'ctrl' => [
        'title' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:' . Newsletter::TABLE_NAME,
        'label' => 'title',
        'tstamp' => 'tstamp',
        'crdate' => 'crdate',
        'cruser_id' => 'cruser_id',
        'languageField' => 'sys_language_uid',
        'transOrigPointerField' => 'l10n_parent',
        'transOrigDiffSourceField' => 'l10n_diffsource',
        'default_sortby' => 'ORDER BY title ASC',
        'delete' => 'deleted',
        'enablecolumns' => [
            'disabled' => 'hidden',
            'starttime' => 'starttime',
            'endtime' => 'endtime',
        ],
        'iconfile' => 'EXT:luxletter/Resources/Public/Icons/' . Newsletter::TABLE_NAME . '.svg',
        'rootLevel' => -1,
        'hideTable' => 1
    ],
    'types' => [
        '1' => [
            'showitem' => 'disabled,title,description,datetime,subject,receiver,configuration,layout,' .
                'origin,bodytext,language'
        ],
    ],
    'columns' => [
        'disabled' => [
            'exclude' => true,
            'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.hidden',
            'config' => [
                'type' => 'check',
                'default' => 0
            ],
        ],
        'title' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.title',
            'config' => [
                'type' => 'input',
                'readOnly' => true,
                'default' => ''
            ]
        ],
        'description' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.description',
            'config' => [
                'type' => 'text',
                'cols' => 500,
                'rows' => 3,
                'readOnly' => true,
                'default' => ''
            ]
        ],
        'datetime' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.datetime',
            'config' => [
                'type' => 'input',
                'size' => 13,
                'eval' => 'datetime',
                'checkbox' => 0,
                'default' => 0,
                'range' => [
                    'lower' => mktime(0, 0, 0, date('m'), date('d'), date('Y'))
                ],
                'readOnly' => true,
                'renderType' => 'inputDateTime'
            ]
        ],
        'subject' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.subject',
            'config' => [
                'type' => 'input',
                'readOnly' => true,
                'default' => ''
            ]
        ],
        'receiver' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.receiver',
            'config' => [
                'type' => 'select',
                'renderType' => 'selectSingle',
                'items' => [
                    ['', 0],
                ],
                'foreign_table' => Usergroup::TABLE_NAME,
                'foreign_table_where' => 'AND 1',
                'default' => 0,
                'readOnly' => true
            ]
        ],
        'configuration' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.configuration',
            'config' => [
                'type' => 'select',
                'renderType' => 'selectSingle',
                'items' => [
                    ['', 0],
                ],
                'foreign_table' => Configuration::TABLE_NAME,
                'foreign_table_where' => 'AND 1',
                'default' => 0,
                'readOnly' => true
            ]
        ],
        'origin' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.origin',
            'config' => [
                'type' => 'input',
                'readOnly' => true,
                'default' => ''
            ]
        ],
        'layout' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.layout',
            'config' => [
                'type' => 'input',
                'readOnly' => true,
                'default' => ''
            ]
        ],
        'bodytext' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.bodytext',
            'config' => [
                'type' => 'text',
                'cols' => 800,
                'rows' => 3,
                'readOnly' => true,
                'default' => ''
            ]
        ],
        'language' => [
            'exclude' => true,
            'label' => 'LLL:EXT:luxletter/Resources/Private/Language/locallang_db.xlf:'
                . Newsletter::TABLE_NAME . '.language',
            'config' => [
                'type' => 'select',
                'special' => 'languages',
                'items' => [
                    [
                        'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.allLanguages',
                        -1,
                        'flags-multiple'
                    ],
                ],
                'renderType' => 'selectSingle',
                'default' => 0
            ]
        ]
    ]
];
